# Bake Forecast CI/CD

## What we implement in this repository

This repo contains code that predicts the number of cookies to bake and implements a lot of DevOps principles

[] Implement the project (code files)
[] Add a simple GHA workflow and make sure it runs until completion
[] Add linting (ruff) and format checks (black)
[] Add typing (mypy) and security checks (bandit)
[] Add test automation
[] Build our Python project
[] Publish the project to both TestPyPi and PyPi when a new release is published
